==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/sliders_horizontal.py <==
from .. import IconBase


class IconSlidersHorizontal(IconBase):
    class_name = "lucide lucide-sliders-horizontal"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "line": {
                "x1": "21",
                "x2": "14",
                "y1": "4",
                "y2": "4"
            }
        },
        {
            "line": {
                "x1": "10",
                "x2": "3",
                "y1": "4",
                "y2": "4"
            }
        },
        {
            "line": {
                "x1": "21",
                "x2": "12",
                "y1": "12",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "8",
                "x2": "3",
                "y1": "12",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "21",
                "x2": "16",
                "y1": "20",
                "y2": "20"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "3",
                "y1": "20",
                "y2": "20"
            }
        },
        {
            "line": {
                "x1": "14",
                "x2": "14",
                "y1": "2",
                "y2": "6"
            }
        },
        {
            "line": {
                "x1": "8",
                "x2": "8",
                "y1": "10",
                "y2": "14"
            }
        },
        {
            "line": {
                "x1": "16",
                "x2": "16",
                "y1": "18",
                "y2": "22"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/sliders_horizontal.py <==
from .. import IconBase


class IconSlidersHorizontal(IconBase):
    class_name = "lucide lucide-sliders-horizontal"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "line": {
                "x1": "21",
                "x2": "14",
                "y1": "4",
                "y2": "4"
            }
        },
        {
            "line": {
                "x1": "10",
                "x2": "3",
                "y1": "4",
                "y2": "4"
            }
        },
        {
            "line": {
                "x1": "21",
                "x2": "12",
                "y1": "12",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "8",
                "x2": "3",
                "y1": "12",
                "y2": "12"
            }
        },
        {
            "line": {
                "x1": "21",
                "x2": "16",
                "y1": "20",
                "y2": "20"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "3",
                "y1": "20",
                "y2": "20"
            }
        },
        {
            "line": {
                "x1": "14",
                "x2": "14",
                "y1": "2",
                "y2": "6"
            }
        },
        {
            "line": {
                "x1": "8",
                "x2": "8",
                "y1": "10",
                "y2": "14"
            }
        },
        {
            "line": {
                "x1": "16",
                "x2": "16",
                "y1": "18",
                "y2": "22"
            }
        }
    ]
}
